@@ -7,6 +7,9 @@
 @description: 
 """
 
+import numpy as np
+from PIL import Image
+
 from torch.utils.data import Dataset
 from torchvision.datasets import CIFAR10, CIFAR100
 
@@ -17,17 +20,26 @@ class CIFAR(Dataset):
 
     def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5), is_cifar100=True):
         if is_cifar100:
-            self.data_set = CIFAR100(root, train=train, transform=transform, target_transform=target_transform,
-                                     download=True)
+            self.data_set = CIFAR100(root, train=train, download=True)
         else:
-            self.data_set = CIFAR10(root, train=train, transform=transform, target_transform=target_transform,
-                                    download=True)
+            self.data_set = CIFAR10(root, train=train, download=True)
         self.classes = self.data_set.classes
         self.root = root
+        self.transform = transform
+        self.target_transform = target_transform
         self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
-        return self.data_set.__getitem__(index)
+        image, target = self.data_set.__getitem__(index)
+        if isinstance(image, Image.Image):
+            image = np.array(image)
+
+        if self.transform is not None:
+            image = self.transform(image)
+        if self.target_transform is not None:
+            target = self.target_transform(target)
+
+        return image, target
 
     def __len__(self) -> int:
         return self.data_set.__len__()
