@@ -7,6 +7,9 @@
 @description: 
 """
 
+import numpy as np
+from PIL import Image
+
 from torch.utils.data import Dataset
 import torchvision.datasets as datasets
 
@@ -18,16 +21,27 @@ class ImageNet(Dataset):
     def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5)):
         split = 'train' if train else 'val'
         # using torchvision ImageNet to get classes
-        self.data_set = datasets.ImageNet(root, split=split, transform=transform, target_transform=target_transform)
+        self.data_set = datasets.ImageNet(root, split=split)
         self.classes = list()
         for class_tuple in self.data_set.classes:
             self.classes.append(','.join(class_tuple))
         self.root = root
+        self.transform = transform
+        self.target_transform = target_transform
         # create evaluator
         self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
-        return self.data_set.__getitem__(index)
+        image, target = self.data_set.__getitem__(index)
+        if isinstance(image, Image.Image):
+            image = np.array(image)
+
+        if self.transform is not None:
+            image = self.transform(image)
+        if self.target_transform is not None:
+            target = self.target_transform(target)
+
+        return image, target
 
     def __len__(self) -> int:
         return len(self.data_set)
