@@ -9,7 +9,7 @@
 
 from torch.nn.parallel import DistributedDataParallel as DDP
 
-from zcls.model.conv_helper import insert_acblock, insert_repvgg_block
+from zcls.model.conv_helper import insert_acblock, insert_repvgg_block, insert_dbblock
 from zcls.model.norm_helper import convert_sync_bn
 import zcls.util.distributed as du
 from zcls.util.checkpoint import CheckPointer
@@ -32,7 +32,6 @@ from .resnet.torchvision_resnet import build_torchvision_resnet
 from .resnet.official_resnest import build_official_resnest
 from .resnet.resnet3d import ResNet3D
 from .ghostnet.ghostnet import GhostNet
-from .efficientnet.efficientnet_lite import EfficientNetLite
 
 logger = logging.get_logger(__name__)
 
@@ -47,11 +46,14 @@ def build_recognizer(cfg, device):
         convert_sync_bn(model, du.LOCAL_PROCESS_GROUP)
     if cfg.MODEL.CONV.ADD_BLOCKS is not None:
         assert isinstance(cfg.MODEL.CONV.ADD_BLOCKS, tuple)
+        logger.info(f'add blocks: {cfg.MODEL.CONV.ADD_BLOCKS}')
         for add_block in cfg.MODEL.CONV.ADD_BLOCKS:
             if add_block == 'RepVGGBlock':
                 insert_repvgg_block(model)
             if add_block == 'ACBlock':
                 insert_acblock(model)
+            if add_block == 'DiverseBranchBlock':
+                insert_dbblock(model)
     preloaded = cfg.MODEL.RECOGNIZER.PRELOADED
     if preloaded != "":
         logger.info(f'load preloaded: {preloaded}')
@@ -59,6 +61,10 @@ def build_recognizer(cfg, device):
         check_pointer.load(preloaded, map_location=device)
         logger.info("finish loading model weights")
 
+    if du.is_master_proc():
+        logger.info(f'full model info:')
+        logger.info(model)
+
     model = model.to(device=device)
     if du.get_world_size() > 1:
         model = DDP(model, device_ids=[device], output_device=device, find_unused_parameters=False)
